==> huaweicloudsdkdds-3.1.110-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/delete_session_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSessionRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sessions': 'list[str]'
    }

    attribute_map = {
        'sessions': 'sessions'
    }

    def __init__(self, sessions=None):
        """DeleteSessionRequestBody

        The model defined in huaweicloud sdk

        :param sessions: 需要终结的会话ID列表。
        :type sessions: list[str]
        """
        
        

        self._sessions = None
        self.discriminator = None

        self.sessions = sessions

    @property
    def sessions(self):
        """Gets the sessions of this DeleteSessionRequestBody.

        需要终结的会话ID列表。

        :return: The sessions of this DeleteSessionRequestBody.
        :rtype: list[str]
        """
        return self._sessions

    @sessions.setter
    def sessions(self, sessions):
        """Sets the sessions of this DeleteSessionRequestBody.

        需要终结的会话ID列表。

        :param sessions: The sessions of this DeleteSessionRequestBody.
        :type sessions: list[str]
        """
        self._sessions = sessions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSessionRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdds-3.1.145-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/delete_session_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSessionRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sessions': 'list[str]'
    }

    attribute_map = {
        'sessions': 'sessions'
    }

    def __init__(self, sessions=None):
        r"""DeleteSessionRequestBody

        The model defined in huaweicloud sdk

        :param sessions: 需要终结的会话ID列表。
        :type sessions: list[str]
        """
        
        

        self._sessions = None
        self.discriminator = None

        self.sessions = sessions

    @property
    def sessions(self):
        r"""Gets the sessions of this DeleteSessionRequestBody.

        需要终结的会话ID列表。

        :return: The sessions of this DeleteSessionRequestBody.
        :rtype: list[str]
        """
        return self._sessions

    @sessions.setter
    def sessions(self, sessions):
        r"""Sets the sessions of this DeleteSessionRequestBody.

        需要终结的会话ID列表。

        :param sessions: The sessions of this DeleteSessionRequestBody.
        :type sessions: list[str]
        """
        self._sessions = sessions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSessionRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
